.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1687: * @file leo.plugins.pygeotag.rst
.. @@language rest
pygeotag Package
================

:mod:`pygeotag` Module
----------------------

.. automodule:: leo.plugins.pygeotag.pygeotag
    :members:
    :undoc-members:
    :show-inheritance:

.. @-leo
